@@ -35,7 +35,7 @@ def test_get_existing_value(cli, dotenv_file):
 
     result = cli.invoke(dotenv_cli, ['--file', dotenv_file, 'get', 'a'])
 
-    assert (result.exit_code, result.output) == (0, "a=b\n")
+    assert (result.exit_code, result.output) == (0, "b\n")
 
 
 def test_get_non_existent_value(cli, dotenv_file):
@@ -124,7 +124,7 @@ def test_get_default_path(tmp_path):
 
     result = sh.dotenv("get", "a")
 
-    assert result == "a=b\n"
+    assert result == "b\n"
 
 
 def test_run(tmp_path):
@@ -138,6 +138,34 @@ def test_run(tmp_path):
     assert result == "b\n"
 
 
+def test_run_with_existing_variable(tmp_path):
+    sh.cd(str(tmp_path))
+    dotenv_file = str(tmp_path / ".env")
+    with open(dotenv_file, "w") as f:
+        f.write("a=b")
+
+    result = sh.dotenv("run", "printenv", "a", _env={"LANG": "en_US.UTF-8", "a": "c"})
+
+    assert result == "b\n"
+
+
+def test_run_with_existing_variable_not_overridden(tmp_path):
+    sh.cd(str(tmp_path))
+    dotenv_file = str(tmp_path / ".env")
+    with open(dotenv_file, "w") as f:
+        f.write("a=b")
+
+    result = sh.dotenv(
+        "run",
+        "--no-override",
+        "printenv",
+        "a",
+        _env={"LANG": "en_US.UTF-8", "a": "c"},
+    )
+
+    assert result == "c\n"
+
+
 def test_run_with_none_value(tmp_path):
     sh.cd(str(tmp_path))
     dotenv_file = str(tmp_path / ".env")
